//
//  SCAdSlot.h
//  SCTVOSSDK
//
//  Copyright © 2019 smartclip. All rights reserved.
//

#import <Foundation/Foundation.h>
#import <CoreGraphics/CoreGraphics.h>

NS_ASSUME_NONNULL_BEGIN
@class SCAdVariants;

/**
 * SCAdSlot: use this class in combination with the SCAdSequencer to define
 *           your adSlots
 */
@interface SCAdSlot : NSObject
/// Array of at tags for this slot (at least one)
@property (nonatomic, readonly, copy)     NSString        *adTag;
/// Variants for this adSlot (opener, closer, bumper)
@property (nonatomic, readonly, strong)     SCAdVariants    *variants;
/// Specify your skipOffset (in seconds) for this slot -1 means no skipOffet
@property (nonatomic, readonly)           NSInteger       skipOffset;
/// Relative time when to start this slot (between 0 and 1)

@property (nonatomic)                     CGFloat relativeSlotTime;
/// force opener playback
@property (nonatomic)                     BOOL forceOpener;
/// force closer playback
@property (nonatomic)                     BOOL forceCloser;
/// force bumper playback
@property (nonatomic)                     BOOL forceBumper;

/// Default initializer
- (instancetype)initWithAdTag:(nonnull NSString*)adTag
              relativeSlotTime:(CGFloat)relativeTime
                      variants:(nullable SCAdVariants*)variants
                    skipOffset:(NSInteger)skipOffset;
@end

NS_ASSUME_NONNULL_END
